Welcome to mirror list, hosted at ThFree Co, Russian Federation.

cygwin.com/git/newlib-cygwin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCorinna Vinschen <corinna@vinschen.de>2004-08-24 13:34:04 +0400
committerCorinna Vinschen <corinna@vinschen.de>2004-08-24 13:34:04 +0400
commit327284cf3ac5f201f8509a77923a88dd886ff4d6 (patch)
tree027f45dd6881c2012479766c0d99487e7ce2d12f /winsup/testsuite/winsup.api
parentd5afcd86f9386ceaa9f04ce7dcee41f49f219c0a (diff)
* winsup.api/ltp/symlink01.c (do_link): Print inode numbers using %llu
format specifier.
Diffstat (limited to 'winsup/testsuite/winsup.api')
-rw-r--r--winsup/testsuite/winsup.api/ltp/symlink01.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/winsup/testsuite/winsup.api/ltp/symlink01.c b/winsup/testsuite/winsup.api/ltp/symlink01.c
index 660a6d2e6..54a24b87f 100644
--- a/winsup/testsuite/winsup.api/ltp/symlink01.c
+++ b/winsup/testsuite/winsup.api/ltp/symlink01.c
@@ -1670,8 +1670,8 @@ struct all_test_cases *tc_ptr;
}
} else {
tst_resm(TFAIL,
- "%sA lstat of %s (ino:%d) and of\n\t\t\
-%s (ino:%d), does not show them being the same ino.", Buffer,
+ "%sA lstat of %s (ino:%llu) and of\n\t\t\
+%s (ino:%llu), does not show them being the same ino.", Buffer,
tc_ptr->fn_arg[1], asymlink.st_ino, "nick", statter.st_ino);
}
}